@@ -162,8 +162,7 @@ class PluginBrowser(Gtk.Window):
         """Fetch list from github project repo and parse JSON"""
 
         if True == Liferea.NetworkMonitor.is_online():
-            print("ONLINE!!!!!!!!!!!!!!!!")
-            list_url = "https://raw.githubusercontent.com/lwindolf/liferea/master/plugins/plugin-list.json"
+            list_url = "https://raw.githubusercontent.com/lwindolf/liferea/liferea-1_14/plugins/plugin-list.json"
             data = None
             req = urllib.request.Request(list_url)
             resp = urllib.request.urlopen(req).read()
@@ -407,6 +406,6 @@ class PluginBrowser(Gtk.Window):
         # arbitrary names...
 
         if error:
-            self.show_message(_("Sorry! Plugin removal failed!."), True)
+            self.show_message(_("Sorry! Plugin removal failed!"), True)
         else:
-            self.show_message(_("Plugin was removed. Please restart Liferea once for it to take full effect!."), False)
+            self.show_message(_("Plugin was removed. Please restart Liferea once for it to take full effect!"), False)
